@@ -98,3 +98,17 @@ def new_add(path, message=''):
         add.close()
     except:
         print("Not {path} file !")
+
+def filename(file, name):
+    try:
+        file_new = file
+        file_name = name
+        os.rename(file_new,file_name)
+        print("重命名成功！")
+        print(f"文件{file_new} 重命名为 {name} ！")
+        print("Rename succeeded!")
+        print(f"Rename succeeded! File {file_new} renamed {name} !")
+    except:
+        print(f"错误！你可能输入了无效路径，或者路径为空！你的路径为：{file_new}")
+        print(f"Wrong! You may have entered an invalid path, or the path is empty! Your path is: {file_new}")
+
